@@ -31,7 +31,12 @@ CLUSTER_TYPE_PERMANENT  = 'permanent'
 # Local cluster id
 LOCAL_CLUSTER_ID = "local"
 
-def get_clusters(api):
+CLUSTER_BACKEND__EMR_HADOOP_1 = "EMR_HADOOP_1"
+CLUSTER_BACKEND__EMR_HADOOP_2 = "EMR_HADOOP_2"
+CLUSTER_BACKEND__ALL          = "ALL"
+
+
+def get_clusters(api, params=None):
     """
     Get recent and running clusters.
     
@@ -43,7 +48,7 @@ def get_clusters(api):
     :rtype: dict:
     :returns: running and recent clusters
     """
-    return api.get('clusters')
+    return api.get('clusters', params)
 
 def stop_cluster(api, cluster_id):
     """
