@@ -41,6 +41,9 @@ COMPLETE_STATUSES = (
     STATUS_SERVICE_ERROR,
     STATUS_STOPPED)
 
+PIG__0_12 = "0.12"
+PIG__0_12_HADOOP_2 = "0.12-Hadoop-2"
+
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=False, pipeline_job_id=None):
